##  What Is an S-User ID?
An S-user ID is a secure login used to access SAP tools and services such as:
  * SAP for Me
  * SAP Support Portal
  * SAP Community


These IDs are essential for submitting support requests, managing workspaces, and accessing product information.
Learn more about S-User IDs in [_Get started with your S-user ID_![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Fmy-support%2Fusers%2Fwelcome.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/en/my-support/users/welcome.html").
